# apscheduler_bundle

[![Build Status](https://travis-ci.org/applauncher-team/apscheduler_bundle.svg?branch=master)](https://travis-ci.org/applauncher-team/apscheduler_bundle)
[![License: MIT](https://img.shields.io/badge/License-MIT-brightgreen.svg)](https://opensource.org/licenses/MIT)



APScheduler support for applauncher
